==> sigutils-2.4.2.tar.gz: sigutils-2.4.2/SigUtils/crypto.py <==
# -*- coding: utf-8 -*-



from M2Crypto import RSA
from M2Crypto.EVP import Cipher
from base64 import b64encode, b64decode
import binascii
import hashlib
import os

ROOT_PATH = os.path.dirname(os.path.abspath(__file__))

ENC = 1
DEC = 0
iv = '\0' * 16

def build_cipher(key, iv, op):
    """"""""
    alg = ['aes_128_ecb', 'aes_128_cbc', 'aes_128_cfb', 'aes_128_ofb']
    return Cipher(alg=alg[2], key=key, iv=iv, op=op)

def encrypt(data, senha='h+aIB6DD3vI='):
    data = data.encode('utf-8')
    cipher = build_cipher(senha, iv, ENC)
    v = cipher.update(data)
    v += cipher.final()
    del cipher
    ret = b64encode(v)
    return ret

def decrypt(data, senha='h+aIB6DD3vI='):
    data = b64decode(data)
    cipher = build_cipher(senha, iv, DEC)
    v = cipher.update(data)
    v += cipher.final()
    del cipher
    return v

def has_message(message):
    md5 = hashlib.md5()
    md5.update(message.encode('utf-8'))
    return md5.hexdigest()
     
def md5_file(file):
    md5 = hashlib.md5()
    if not os.path.exists(file):
        raise IOError('[Errno 2] Arquivo ou diretório não encontrado: %s' % file)
    try:
        with open(file, 'rb') as f: 
            for chunk in iter(lambda: f.read(8192), ''):
                md5.update(chunk)
        retval = md5.hexdigest()
    except Exception, e:
        raise e
    return retval

def assinatura(message, pkey):
    key = RSA.load_key_string(pkey)
    sign = key.sign(has_message(message))
    return binascii.b2a_hex(sign)

def verifica_assinatura(message, sign, pkey):
    key = RSA.load_key_string(pkey)
    try:
        sign = binascii.a2b_hex(sign)
        retval = key.verify(has_message(message), sign)
    except RSA.RSAError, e:
        retval = 0
        print e
    return retval
        
def assinatura_ead(file, pkey_sig, prefix='EAD'):
    if not os.path.exists(file):
        raise IOError('[Errno 2] Arquivo ou diretório não encontrado: %s' % file)
    try:
        f_hash = md5_file(file)
        pkey = RSA.load_key_string(pkey_sig)
        sign = binascii.b2a_hex(pkey.sign(f_hash))
        sign = '%s%s' % (prefix, sign)
        string = open(file, 'r').read()
        string += sign
        assina = open(file, 'w')
        assina.write(string)
        assina.close()
    except Exception, e:
        raise e
    return sign

def crypt(texto, acao):
    if type(texto) == float:
        texto = str(texto)
    _texto = texto.upper()
    j = len(_texto)
    if not j:
        return
    ACrypt = ['X709UTPS2EA6MG3QKL1FD8Y4HVNOJIRWBC5Z', 'C6KRS7O1UL30IHP8JDVFTN4AY9EXQWB2MG5Z',
              'Y56AD42SH3P1MEBN0FQJCL9RVO7UW8XITGKZ', '53YEXLC2O6T8GIJ0RPU1VDAQSW4M9KNFBH7Z',
              '0MUR25T1W4YPQOX8VFANSD7LKBE63G9JHICZ', 'ACEWXML59J2YO6UF1T0B4GQ3DIP7N8KRSVHZ',
              'T0UBCFX5EGSJ73HKQAPR18ML4O6DIWYN2V9Z', '5XMTDSC3K1OV0AL4BHEUYRF7IWP6GN9J8Q2Z',
              '0783JSABCLO6TXUV4IR2EMHFGNQ5Y9K1DPWZ', 'EJ6WQVBDTLOC9GN3H7P5FY1MS4R8U20XIAKZ',
              'UVP9KBTFONC4E5HRGI162Q0SWXL37MYDJA8Z', 'R7EGWYPVLAKI8D9JXFQ4H035O2BTCUM16SNZ',
              'N7IJ2YTG86K3PQEDR015UOFBCWAMHX4SL9VZ', 'VLIHKWQYXPFG846SE5A7BT3M0NOUDRC129JZ',
              'MKHS752UX40G9CA1LWYVJDPRBONITE38F6QZ', 'Y2IXUANB1L8HMJQ3SPDR970OWVTC6EGK4F5Z',
              '2THAK30QGPSOW1E7UJNRI4LDYVBFM96X5C8Z', 'VHFYR3G4LQKTX5UIWBA21N78960POSDEMCJZ',
              'B062DOY3GQKSEJF8AMUXPC7TVR1HL94NIW5Z', 'X36EV7K90BMDIC8GOTSHJAN5W1PYQFRL24UZ',
              'DVGXWEFJT9MY374ASQO1KH6205ULRNIB8PCZ', '6A79VH2LOJIKNRTYXWG3BE81F4D5CSP0QMUZ',
              '3Y1DWA4FJSPHELOM8TKX6GU2BV5QNI7C90RZ', '7DBA2SC68W4MN1P9GUYTE0O3QJXL5HRVKIFZ',
              '80AJBMQVSF71K6ULCX4GW5NYTDRE23HI9POZ', 'PXC6QNGJO4E8M95ASFWTR2B1H3DL7VYU0KIZ',
              'BE8U2CKFPO4TS13QM0HG5DNAWVJLI67R9XYZ', 'PYX5E6Q1G4WAMF7KHS8O92TJRDCB0LU3VNIZ',
              'W54RJ03INTSXP7QMLCFY2EGBV691KA8ODUHZ', '1ROY7PD0V4BA952TUGXS8EF6HCQNK3JIMLWZ',
              '23CES0WRMFP4XOQT1LNJYGBH7AVUD698I5KZ', 'MGYSP74AIR8E1WVQLDN0XOJU9KC523FTBH6Z',
              '49BO5DAU18J0HTQSC7XLYG3NIFEKWRPV6M2Z', '03RB2DIHFLNPVU981SC75OTJWXAG4QEYKM6Z',
              'F5BVD89HP0GKL3OUTS1Y4CQERXMNWIA7J26Z', '5DT07EQ68RNUBM2OIPY1CJKVGXH4FW39ASLZ',
              '5XY1KA2COW78LESRG0NBPVI4F6HMQ93DTUJZ', '2YFOX9IL03WR7TPKHNBM56JDE1Q8GVU4CASZ',
              '0QP8N3KT4XILO9VARBFUSMWG1Y7H5D6J2ECZ', 'PIFG5Q29M3E6OHXYC1DKL8R0BTUNWVSJ7A4Z',
              'S7W9ENBGOPY8Q1I024UXHJRCF3ALMKV56TDZ', 'PBNSCJ5YUQHD7I3KFOV8XGW40AT61LE9MR2Z',
              'RYLE6AMHTSX0BO1J7DP8GKQ4FN593WI2VUCZ', '8G3N9J7TY25VSDLBMUCQEAX4P0WF6KOIHR1Z',
              'O4GW36KDBJPT72Q90VHYMNAURFL5E18XCISZ', 'DICNOTP5LJQV0FMSAE362HRUX8W14G7KY9BZ',
              'TUBQ6F1HDXP58WKG7ERJLOA2V40SI39NCYMZ', '7G1O49SWVLNHDUE8C3QXJY2KABPTMFR5I06Z',
              'XIM504HN98612S7YDPRGQJEBVU3KWTCLAFOZ', 'F1QM4UY9NVG7RITPW5JSDEHKB08LOCA36X2Z',
              'X709UTPS2EA6MG3QKL1FD8Y4HVNOJIRWBC5Z', 'C6KRS7O1UL30IHP8JDVFTN4AY9EXQWB2MG5Z',
              'Y56AD42SH3P1MEBN0FQJCL9RVO7UW8XITGKZ', '53YEXLC2O6T8GIJ0RPU1VDAQSW4M9KNFBH7Z',
              '0MUR25T1W4YPQOX8VFANSD7LKBE63G9JHICZ', 'ACEWXML59J2YO6UF1T0B4GQ3DIP7N8KRSVHZ',
              'T0UBCFX5EGSJ73HKQAPR18ML4O6DIWYN2V9Z', '5XMTDSC3K1OV0AL4BHEUYRF7IWP6GN9J8Q2Z',
              '0783JSABCLO6TXUV4IR2EMHFGNQ5Y9K1DPWZ', 'EJ6WQVBDTLOC9GN3H7P5FY1MS4R8U20XIAKZ',
              'UVP9KBTFONC4E5HRGI162Q0SWXL37MYDJA8Z', 'R7EGWYPVLAKI8D9JXFQ4H035O2BTCUM16SNZ',
              'N7IJ2YTG86K3PQEDR015UOFBCWAMHX4SL9VZ', 'VLIHKWQYXPFG846SE5A7BT3M0NOUDRC129JZ',
              'MKHS752UX40G9CA1LWYVJDPRBONITE38F6QZ', 'Y2IXUANB1L8HMJQ3SPDR970OWVTC6EGK4F5Z',
              '2THAK30QGPSOW1E7UJNRI4LDYVBFM96X5C8Z', 'VHFYR3G4LQKTX5UIWBA21N78960POSDEMCJZ',
              'B062DOY3GQKSEJF8AMUXPC7TVR1HL94NIW5Z', 'X36EV7K90BMDIC8GOTSHJAN5W1PYQFRL24UZ',
              'DVGXWEFJT9MY374ASQO1KH6205ULRNIB8PCZ', '6A79VH2LOJIKNRTYXWG3BE81F4D5CSP0QMUZ',
              '3Y1DWA4FJSPHELOM8TKX6GU2BV5QNI7C90RZ', '7DBA2SC68W4MN1P9GUYTE0O3QJXL5HRVKIFZ',
              '80AJBMQVSF71K6ULCX4GW5NYTDRE23HI9POZ', 'PXC6QNGJO4E8M95ASFWTR2B1H3DL7VYU0KIZ',
              'BE8U2CKFPO4TS13QM0HG5DNAWVJLI67R9XYZ', 'PYX5E6Q1G4WAMF7KHS8O92TJRDCB0LU3VNIZ',
              'W54RJ03INTSXP7QMLCFY2EGBV691KA8ODUHZ', '1ROY7PD0V4BA952TUGXS8EF6HCQNK3JIMLWZ',
              '23CES0WRMFP4XOQT1LNJYGBH7AVUD698I5KZ', 'MGYSP74AIR8E1WVQLDN0XOJU9KC523FTBH6Z',
              '49BO5DAU18J0HTQSC7XLYG3NIFEKWRPV6M2Z', '03RB2DIHFLNPVU981SC75OTJWXAG4QEYKM6Z',
              'F5BVD89HP0GKL3OUTS1Y4CQERXMNWIA7J26Z', '5DT07EQ68RNUBM2OIPY1CJKVGXH4FW39ASLZ',
              '5XY1KA2COW78LESRG0NBPVI4F6HMQ93DTUJZ', '2YFOX9IL03WR7TPKHNBM56JDE1Q8GVU4CASZ',
              '0QP8N3KT4XILO9VARBFUSMWG1Y7H5D6J2ECZ', 'PIFG5Q29M3E6OHXYC1DKL8R0BTUNWVSJ7A4Z',
              'S7W9ENBGOPY8Q1I024UXHJRCF3ALMKV56TDZ', 'PBNSCJ5YUQHD7I3KFOV8XGW40AT61LE9MR2Z',
              'RYLE6AMHTSX0BO1J7DP8GKQ4FN593WI2VUCZ', '8G3N9J7TY25VSDLBMUCQEAX4P0WF6KOIHR1Z',
              'O4GW36KDBJPT72Q90VHYMNAURFL5E18XCISZ', 'DICNOTP5LJQV0FMSAE362HRUX8W14G7KY9BZ',
              'TUBQ6F1HDXP58WKG7ERJLOA2V40SI39NCYMZ', '7G1O49SWVLNHDUE8C3QXJY2KABPTMFR5I06Z',
              'XIM504HN98612S7YDPRGQJEBVU3KWTCLAFOZ', 'F1QM4UY9NVG7RITPW5JSDEHKB08LOCA36X2Z']
    MainStr = 'ABCDEFGHIJKLMNOPQRSTUVWXYZ0123456789'

    resultado = ''
    pos_texto = 1
    for letra in _texto:
        pos_Main = 0
        if acao == 'C':
            base = MainStr
            inv_base = ACrypt[pos_texto]
        else:
            base = ACrypt[pos_texto]
            inv_base = MainStr
        for letra_base in base:
            if letra == letra_base.encode('utf-8'):
                resultado += str(inv_base[pos_Main])
                break
            pos_Main += 1
        if pos_Main == 36: # nao achou correspondente, usa a propria letra
            resultado = resultado + letra
        pos_texto += 1
    return resultado

==> sigutils-3.1.11.tar.gz: sigutils-3.1.11/SigUtils/crypto.py <==
# -*- coding: utf-8 -*-



from M2Crypto import RSA
from M2Crypto.EVP import Cipher
from base64 import b64encode, b64decode
import binascii
import hashlib
import os

ROOT_PATH = os.path.dirname(os.path.abspath(__file__))

ENC = 1
DEC = 0
iv = b'\0' * 16

def build_cipher(key, iv, op):
    """"""""
    alg = ['aes_128_ecb', 'aes_128_cbc', 'aes_128_cfb', 'aes_128_ofb']
    return Cipher(alg=alg[2], key=key, iv=iv, op=op)

def encrypt(data, senha='h+aIB6DD3vI='):
    data = data.encode('utf-8')
    cipher = build_cipher(senha, iv, ENC)
    v = cipher.update(data)
    v += cipher.final()
    del cipher
    ret = b64encode(v)
    return ret

def decrypt(data, senha='h+aIB6DD3vI='):
    data = b64decode(data)
    cipher = build_cipher(senha, iv, DEC)
    v = cipher.update(data)
    v += cipher.final()
    del cipher
    return v

def has_message(message):
    md5 = hashlib.md5()
    md5.update(message)
    return md5.hexdigest().encode()
     
def md5_file(file):
    md5 = hashlib.md5()
    if not os.path.exists(file):
        raise IOError('[Errno 2] Arquivo ou diretório não encontrado: %s' % file)
    try:
        with open(file, 'rb') as f: 
            for chunk in iter(lambda: f.read(8192), ''):
                md5.update(chunk)
        retval = md5.hexdigest()
    except Exception as e:
        raise e
    return retval

def assinatura(message, pkey):
    key = RSA.load_key_string(pkey)
    sign = key.sign(has_message(message))
    return binascii.b2a_hex(sign)

def verifica_assinatura(message, sign, pkey):
    key = RSA.load_key_string(pkey)
    try:
        sign = binascii.a2b_hex(sign)
        retval = key.verify(has_message(message), sign)
    except RSA.RSAError as e:
        retval = 0
        print(e)
    return retval
        
def assinatura_ead(file, pkey_sig, prefix='EAD'):
    if not os.path.exists(file):
        raise IOError('[Errno 2] Arquivo ou diretório não encontrado: %s' % file)
    try:
        f_hash = md5_file(file)
        pkey = RSA.load_key_string(pkey_sig)
        sign = binascii.b2a_hex(pkey.sign(f_hash))
        sign = '%s%s' % (prefix, sign)
        string = open(file, 'r').read()
        string += sign
        assina = open(file, 'w')
        assina.write(string)
        assina.close()
    except Exception as e:
        raise e
    return sign

def crypt(texto, acao):
    if type(texto) == float:
        texto = str(texto)
    _texto = texto.upper()
    j = len(_texto)
    if not j:
        return
    ACrypt = ['X709UTPS2EA6MG3QKL1FD8Y4HVNOJIRWBC5Z', 'C6KRS7O1UL30IHP8JDVFTN4AY9EXQWB2MG5Z',
              'Y56AD42SH3P1MEBN0FQJCL9RVO7UW8XITGKZ', '53YEXLC2O6T8GIJ0RPU1VDAQSW4M9KNFBH7Z',
              '0MUR25T1W4YPQOX8VFANSD7LKBE63G9JHICZ', 'ACEWXML59J2YO6UF1T0B4GQ3DIP7N8KRSVHZ',
              'T0UBCFX5EGSJ73HKQAPR18ML4O6DIWYN2V9Z', '5XMTDSC3K1OV0AL4BHEUYRF7IWP6GN9J8Q2Z',
              '0783JSABCLO6TXUV4IR2EMHFGNQ5Y9K1DPWZ', 'EJ6WQVBDTLOC9GN3H7P5FY1MS4R8U20XIAKZ',
              'UVP9KBTFONC4E5HRGI162Q0SWXL37MYDJA8Z', 'R7EGWYPVLAKI8D9JXFQ4H035O2BTCUM16SNZ',
              'N7IJ2YTG86K3PQEDR015UOFBCWAMHX4SL9VZ', 'VLIHKWQYXPFG846SE5A7BT3M0NOUDRC129JZ',
              'MKHS752UX40G9CA1LWYVJDPRBONITE38F6QZ', 'Y2IXUANB1L8HMJQ3SPDR970OWVTC6EGK4F5Z',
              '2THAK30QGPSOW1E7UJNRI4LDYVBFM96X5C8Z', 'VHFYR3G4LQKTX5UIWBA21N78960POSDEMCJZ',
              'B062DOY3GQKSEJF8AMUXPC7TVR1HL94NIW5Z', 'X36EV7K90BMDIC8GOTSHJAN5W1PYQFRL24UZ',
              'DVGXWEFJT9MY374ASQO1KH6205ULRNIB8PCZ', '6A79VH2LOJIKNRTYXWG3BE81F4D5CSP0QMUZ',
              '3Y1DWA4FJSPHELOM8TKX6GU2BV5QNI7C90RZ', '7DBA2SC68W4MN1P9GUYTE0O3QJXL5HRVKIFZ',
              '80AJBMQVSF71K6ULCX4GW5NYTDRE23HI9POZ', 'PXC6QNGJO4E8M95ASFWTR2B1H3DL7VYU0KIZ',
              'BE8U2CKFPO4TS13QM0HG5DNAWVJLI67R9XYZ', 'PYX5E6Q1G4WAMF7KHS8O92TJRDCB0LU3VNIZ',
              'W54RJ03INTSXP7QMLCFY2EGBV691KA8ODUHZ', '1ROY7PD0V4BA952TUGXS8EF6HCQNK3JIMLWZ',
              '23CES0WRMFP4XOQT1LNJYGBH7AVUD698I5KZ', 'MGYSP74AIR8E1WVQLDN0XOJU9KC523FTBH6Z',
              '49BO5DAU18J0HTQSC7XLYG3NIFEKWRPV6M2Z', '03RB2DIHFLNPVU981SC75OTJWXAG4QEYKM6Z',
              'F5BVD89HP0GKL3OUTS1Y4CQERXMNWIA7J26Z', '5DT07EQ68RNUBM2OIPY1CJKVGXH4FW39ASLZ',
              '5XY1KA2COW78LESRG0NBPVI4F6HMQ93DTUJZ', '2YFOX9IL03WR7TPKHNBM56JDE1Q8GVU4CASZ',
              '0QP8N3KT4XILO9VARBFUSMWG1Y7H5D6J2ECZ', 'PIFG5Q29M3E6OHXYC1DKL8R0BTUNWVSJ7A4Z',
              'S7W9ENBGOPY8Q1I024UXHJRCF3ALMKV56TDZ', 'PBNSCJ5YUQHD7I3KFOV8XGW40AT61LE9MR2Z',
              'RYLE6AMHTSX0BO1J7DP8GKQ4FN593WI2VUCZ', '8G3N9J7TY25VSDLBMUCQEAX4P0WF6KOIHR1Z',
              'O4GW36KDBJPT72Q90VHYMNAURFL5E18XCISZ', 'DICNOTP5LJQV0FMSAE362HRUX8W14G7KY9BZ',
              'TUBQ6F1HDXP58WKG7ERJLOA2V40SI39NCYMZ', '7G1O49SWVLNHDUE8C3QXJY2KABPTMFR5I06Z',
              'XIM504HN98612S7YDPRGQJEBVU3KWTCLAFOZ', 'F1QM4UY9NVG7RITPW5JSDEHKB08LOCA36X2Z',
              'X709UTPS2EA6MG3QKL1FD8Y4HVNOJIRWBC5Z', 'C6KRS7O1UL30IHP8JDVFTN4AY9EXQWB2MG5Z',
              'Y56AD42SH3P1MEBN0FQJCL9RVO7UW8XITGKZ', '53YEXLC2O6T8GIJ0RPU1VDAQSW4M9KNFBH7Z',
              '0MUR25T1W4YPQOX8VFANSD7LKBE63G9JHICZ', 'ACEWXML59J2YO6UF1T0B4GQ3DIP7N8KRSVHZ',
              'T0UBCFX5EGSJ73HKQAPR18ML4O6DIWYN2V9Z', '5XMTDSC3K1OV0AL4BHEUYRF7IWP6GN9J8Q2Z',
              '0783JSABCLO6TXUV4IR2EMHFGNQ5Y9K1DPWZ', 'EJ6WQVBDTLOC9GN3H7P5FY1MS4R8U20XIAKZ',
              'UVP9KBTFONC4E5HRGI162Q0SWXL37MYDJA8Z', 'R7EGWYPVLAKI8D9JXFQ4H035O2BTCUM16SNZ',
              'N7IJ2YTG86K3PQEDR015UOFBCWAMHX4SL9VZ', 'VLIHKWQYXPFG846SE5A7BT3M0NOUDRC129JZ',
              'MKHS752UX40G9CA1LWYVJDPRBONITE38F6QZ', 'Y2IXUANB1L8HMJQ3SPDR970OWVTC6EGK4F5Z',
              '2THAK30QGPSOW1E7UJNRI4LDYVBFM96X5C8Z', 'VHFYR3G4LQKTX5UIWBA21N78960POSDEMCJZ',
              'B062DOY3GQKSEJF8AMUXPC7TVR1HL94NIW5Z', 'X36EV7K90BMDIC8GOTSHJAN5W1PYQFRL24UZ',
              'DVGXWEFJT9MY374ASQO1KH6205ULRNIB8PCZ', '6A79VH2LOJIKNRTYXWG3BE81F4D5CSP0QMUZ',
              '3Y1DWA4FJSPHELOM8TKX6GU2BV5QNI7C90RZ', '7DBA2SC68W4MN1P9GUYTE0O3QJXL5HRVKIFZ',
              '80AJBMQVSF71K6ULCX4GW5NYTDRE23HI9POZ', 'PXC6QNGJO4E8M95ASFWTR2B1H3DL7VYU0KIZ',
              'BE8U2CKFPO4TS13QM0HG5DNAWVJLI67R9XYZ', 'PYX5E6Q1G4WAMF7KHS8O92TJRDCB0LU3VNIZ',
              'W54RJ03INTSXP7QMLCFY2EGBV691KA8ODUHZ', '1ROY7PD0V4BA952TUGXS8EF6HCQNK3JIMLWZ',
              '23CES0WRMFP4XOQT1LNJYGBH7AVUD698I5KZ', 'MGYSP74AIR8E1WVQLDN0XOJU9KC523FTBH6Z',
              '49BO5DAU18J0HTQSC7XLYG3NIFEKWRPV6M2Z', '03RB2DIHFLNPVU981SC75OTJWXAG4QEYKM6Z',
              'F5BVD89HP0GKL3OUTS1Y4CQERXMNWIA7J26Z', '5DT07EQ68RNUBM2OIPY1CJKVGXH4FW39ASLZ',
              '5XY1KA2COW78LESRG0NBPVI4F6HMQ93DTUJZ', '2YFOX9IL03WR7TPKHNBM56JDE1Q8GVU4CASZ',
              '0QP8N3KT4XILO9VARBFUSMWG1Y7H5D6J2ECZ', 'PIFG5Q29M3E6OHXYC1DKL8R0BTUNWVSJ7A4Z',
              'S7W9ENBGOPY8Q1I024UXHJRCF3ALMKV56TDZ', 'PBNSCJ5YUQHD7I3KFOV8XGW40AT61LE9MR2Z',
              'RYLE6AMHTSX0BO1J7DP8GKQ4FN593WI2VUCZ', '8G3N9J7TY25VSDLBMUCQEAX4P0WF6KOIHR1Z',
              'O4GW36KDBJPT72Q90VHYMNAURFL5E18XCISZ', 'DICNOTP5LJQV0FMSAE362HRUX8W14G7KY9BZ',
              'TUBQ6F1HDXP58WKG7ERJLOA2V40SI39NCYMZ', '7G1O49SWVLNHDUE8C3QXJY2KABPTMFR5I06Z',
              'XIM504HN98612S7YDPRGQJEBVU3KWTCLAFOZ', 'F1QM4UY9NVG7RITPW5JSDEHKB08LOCA36X2Z']
    MainStr = 'ABCDEFGHIJKLMNOPQRSTUVWXYZ0123456789'

    resultado = ''
    pos_texto = 1
    for letra in _texto:
        pos_Main = 0
        if acao == 'C':
            base = MainStr
            inv_base = ACrypt[pos_texto]
        else:
            base = ACrypt[pos_texto]
            inv_base = MainStr
        for letra_base in base:
            if letra == letra_base.encode('utf-8'):
                resultado += str(inv_base[pos_Main])
                break
            pos_Main += 1
        if pos_Main == 36: # nao achou correspondente, usa a propria letra
            resultado = resultado + letra
        pos_texto += 1
    return resultado
